package message_queue

import (
	"git.sxidc.com/go-framework/baize/framework/core/infrastructure/message_queue/common"
)

// NewCloudEvent 创建CloudEventType
// 参数：
// - eventID: 事件ID，可以使用实体ID
// - eventType事件类型: 一般为领域.操作，如project.create
// - data: 事件的数据
// 返回值:
// - CloudEvent
func NewCloudEvent(eventID string, eventType string, data string) *common.CloudEvent {
	return common.NewCloudEvent(eventID, eventType, data)
}

// Subscribe 订阅
// 参数:
// - queue: 消息队列
// - group: 消息组，不同的消息组的订阅者都能收到某一个主题的消息，同一个消息组的消费者只有一个能够消费消息
// - topic: 主题
// - handler: 消息处理函数
// 返回值:
// - 错误
func Subscribe(messageQueue common.MessageQueue, group string, topic string, handler common.MessageHandler) error {
	return messageQueue.Subscribe(group, topic, handler)
}

// UnSubscribe 取消订阅
// 参数:
// - queue: 消息队列
// - group: 消息组，不同的消息组的订阅者都能收到某一个主题的消息，同一个消息组的消费者只有一个能够消费消息
// - topic: 主题
// 返回值:
// - 错误
func UnSubscribe(messageQueue common.MessageQueue, group string, topic string) error {
	return messageQueue.UnSubscribe(group, topic)
}

// Publish 发布消息
// 参数:
// - queue: 消息队列
// - topic: 主题
// - event: CloudEvent
// 返回值:
// - 错误
func Publish(messageQueue common.MessageQueue, topic string, event *common.CloudEvent) error {
	return messageQueue.Publish(topic, event)
}
